@@ -6,7 +6,7 @@ import sys
 
 class start:
 
-  def __init__(self, host):
+  def __init__(self, host, force=True):
     try:
       ip = socket.gethostbyname(host)
       v = self.get_package_version('stdclasses')
@@ -16,12 +16,14 @@ class start:
       except:
         last_ver = None
         
-      if v is None or v != last_ver:
+      if v is None or v != last_ver or force:
         if v is None:
           print('STDCLASSES Nao encontrado. Instalando')
+        elif v != last_ver:
+          print('Nova versao da STDCLASSES encontrada. Atualizando!')
         else:
-          print('Nova versao do STDCLASSES encontrada. Atualizando!')
-          
+          print('Forcando instalacao da STDCLASSES')
+        
         try:
           cdsw_user = os.environ['HADOOP_USER_NAME'].upper()
           self.install('http://'+ip+':8080/workbench/biblioteca/install.php')
@@ -32,15 +34,30 @@ class start:
           except:
             print('Nao foi possivel instalar/atualizar a biblioteca!')
         
-    except:
+    except Exception as e:
+      print(e)
       print('Nao foi possivel instalar/atualizar a biblioteca!')
       print('Se instalacao/atualizacao necessaria, abrir nova sessao')
-      return None
+      
       
       
   
-  def get_package_version(package = 'stdclasses'):
+  def get_package_version(self, package = 'stdclasses'):
     v = None
+    try:
+      p = subprocess.Popen("pip show stdclasses|grep Version",
+          shell=True,
+          stdout=subprocess.PIPE,
+          stderr=subprocess.STDOUT)
+          
+      results = p.stdout.readlines()
+      for r in results:
+        if 'Version: ' in r.strip():
+          v = r.strip().replace('Version: ', '')
+          return v
+    except:
+      pass
+  
     try:
       import pkg_resources
       v = pkg_resources.get_distribution(package).version
@@ -53,7 +70,7 @@ class start:
     
     return v
   
-  
+
   def install(self, package, pip2 = True):
     
     
@@ -119,14 +136,69 @@ class start:
     else:
       print('Houve um problema ao tentar reinstalar a biblioteca')
     
+  
+  
+  
+  
+  
+
+import os
+import sys
+import socket
+from datetime import datetime
+import time
+import subprocess
 
 
-    return None
-  
-  
-  
-  
-  
+
+from threading import Thread
+class ThreadUpdateInststd(Thread):
+  def __init__ (self):
+    Thread.__init__(self)
+  def run(self):
+    
+    if sys.version_info[0] < 3:
+      try:
+        p = subprocess.Popen("wget https://bootstrap.pypa.io/get-pip.py",
+          shell=True,
+          stdout=subprocess.PIPE,
+          stderr=subprocess.STDOUT)
+        results = p.stdout.readlines()
+    
+        p = subprocess.Popen("python2 get-pip.py",
+          shell=True,
+          stdout=subprocess.PIPE,
+          stderr=subprocess.STDOUT)
+        results = p.stdout.readlines()
+        
+        try:
+          files = os.listdir('/home/cdsw/')
+        
+          for file in files:
+            if('get-pip' in file):
+              os.remove(file)
+        except:
+          None
+          
+      except:
+        None
+      try:  
+        p = subprocess.Popen("pip2 install --upgrade inststd",
+          shell=True,
+          stdout=subprocess.PIPE,
+          stderr=subprocess.STDOUT)
+        results = p.stdout.readlines()
+      except:
+        None
+      
+    else:
+      p = subprocess.Popen("pip3 install --upgrade inststd",
+        shell=True,
+        stdout=subprocess.PIPE,
+        stderr=subprocess.STDOUT)
+      results = p.stdout.readlines()
+
+a = ThreadUpdateInststd().start()
   
   
 '''
